/* Based on Scribe's OAuth documentation
 *
 * In this example we describe the steps required to perform
 * user authentication against SAPO's Login infrastructure.
 *
 * Note that, since this is a CLI application, the out-of-band
 * callback mode is used. In a web application the URL callback
 * method is preferred.
 *
 */

package pt.sapo.connect;

import java.io.IOException;
import java.util.Scanner;

import org.scribe.builder.ServiceBuilder;
import org.scribe.model.OAuthRequest;
import org.scribe.model.Response;
import org.scribe.model.Token;
import org.scribe.model.Verb;
import org.scribe.model.Verifier;
import org.scribe.oauth.OAuthService;

public class AccessProtectedResourceExample {

    private static final String SAPO_USER_PHOTOS = "https://services.sapo.pt/Photos/ImageGetListByUser";

    private static final String CALLBACK_URL = "oob";
    //private static final String CALLBACK_URL = "https://localhost/oauth/"

    /**
     * @param args
     * @throws IOException
     */
    public static void main(String[] args) throws IOException {

        if (args.length < 2) {
            System.out.println("Please specify the consumer key and secret.");
            return;
        }

        String consumerKey = args[0];
        String consumerSecret = args[1];

        OAuthService service = new ServiceBuilder()
        .provider(SAPOConnectApi.class)
        .apiKey(consumerKey)
        .apiSecret(consumerSecret)
        .callback(CALLBACK_URL)
        .build();

        Scanner in = new Scanner(System.in);

        System.out.println("=== Access a protected resource workflow ===");
        System.out.println();

        // Obtain the Request Token
        System.out.println("Fetching the Request Token...");
        Token requestToken = service.getRequestToken();
        System.out.println("Got the Request Token!");
        System.out.println();

        System.out.println("Now go and authorize us to fetch your public info (so we can log you in):");
        System.out.println(service.getAuthorizationUrl(requestToken));
        System.out.println("And paste the PIN here");
        System.out.print(">>");
        Verifier verifier = new Verifier(in.nextLine());
        System.out.println();

        // Trade the Request Token and Verifier for the Access Token
        System.out.println("Trading the Request Token for an Access Token...");
        Token accessToken = service.getAccessToken(requestToken, verifier);
        System.out.println("Got the Access Token!");
        System.out.println("(if you're curious it looks like this: " + accessToken + " )");
        System.out.println();
        // Now let's go and ask for a protected resource!
        System.out.println("Now we're going to list your photos.");
        OAuthRequest request = new OAuthRequest(Verb.GET, SAPO_USER_PHOTOS);
        service.signRequest(accessToken, request);
        Response response = request.send();
        System.out.println("Received a response! Lets see what we found...");
        System.out.println();
        System.out.println(response.getBody());
      }
}
